#!/usr/bin/env python3
"""
SMTP Enumerator
Parameters:
    - IP: Target IP address
    - port: Target port (default: 25)
"""
import smtplib
import socket
import argparse
import sys

def enumerate_smtp(ip, port=25):
    try:
        # Create socket connection
        sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
        sock.connect((ip, port))
        banner = sock.recv(1024).decode()
        print(f"Banner: {banner}")
        
        # Test SMTP commands
        commands = [
            'HELP', 'HELO test.com', 'EHLO test.com',
            'VRFY root', 'EXPN root'
        ]
        
        for command in commands:
            print(f"\nTesting command: {command}")
            sock.send(f"{command}\r\n".encode())
            response = sock.recv(1024).decode()
            print(f"Response: {response}")
            
        sock.close()
    except Exception as e:
        print(f"Error: {str(e)}")
        sys.exit(1)

if __name__ == "__main__":
    parser = argparse.ArgumentParser(description="SMTP Enumerator")
    parser.add_argument("ip", help="Target IP address")
    parser.add_argument("--port", type=int, default=25, help="Target port (default: 25)")
    args = parser.parse_args()
    
    enumerate_smtp(args.ip, args.port)
